#!/bin/sh
#
# Lance Spitzner <lance@honeynet.org>
# November 27, 2002
#
# PURPOSE: The purpose of this script is to take an
# existing Snort 1.9 rules set and convert it for use
# with a Honeynet using Snort-Inline.  A Honeynet is
# a type of honeypot, it is a network designed to be
# compromised.  You can learn more at
#
#    http://www.honeynet.org/papers/honeynet/
#
# Snort-Inline is a Data Control mechanism used for
# Honeynets, it acts as an IDS Gateway, the ability
# to detect and block attacks.  This script takes
# the existing Snort rule set, and changes all 'alerts'
# to 'drop'.  Thus, detected attacks are not only
# alerted, but dropped.
#
# WARNING!  You do not want to use this script to
# to create rules for production environments.  This
# script will create an ass-backwards rule set.  It
# will allow any inbound attacks, but block any
# outbound attacks once your network has been hacked.
# Sounds odd, but for a Honeynet, this is exactly what
# we want.
#
# To execute this script, simply copy it in the same
# directory as the Snort rule set you want to convert.
# No need to run this as root.


###  Basics
PATH=/bin:/usr/bin

### Variables
TMP=.rule_$$

#### Execution  ######
## Uncomment this line if you want to convert all the rules files
#for x in `ls *.rules`

## Uncomment this line if you want to convert only specific rules files listed 
## in rules.txt
#for x in `cat rules.txt`

for x in smtp.rules
do
   echo "Converting rule $p in $x to use the DROP command for Honeynets"
   cat $x | sed \
   -e "s/EXTERNAL_NET/HONEYNET_NET/g" -e "s/HOME_NET/EXTERNAL_NET/g" \
   -e "s/SMTP_SERVERS/EXTERNAL_NET/g"  -e "s/HTTP_SERVERS/EXTERNAL_NET/g" \
   -e "s/SQL_SERVERS/EXTERNAL_NET/g"   -e "s/DNS_SERVERS/EXTERNAL_NET/g" \
   -e "s/TELNET_SERVERS/EXTERNAL_NET/g" -e "s/alert /drop /g" > $TMP
   cat $TMP > $x
done
